/* IMS F006A example program
   Copyright INMOS Limited 1991 */

/* Ethernet loopback example. This program uses the IMS F006A
   diagnostic loopback procedures to perform internal and external
   loopback tests. After each test, Ethernet statistics are requested
   from the device driver, and displayed. */

#include <misc.h>
#include <stdio.h>
#include <stdlib.h>
#include <channel.h>
#include <b431io.h>
#include <b431test.h>

/* print the Ethernet statistics structure */

void print_ether_stats( ETHER_STATS ether_stats )
{
	printf( "Ethernet statistics:\n" );
	printf( "tx_packets = %lu, ", ether_stats.tx_packets );
	printf( "rx_packets = %lu\n", ether_stats.rx_packets );
	printf( "framing_errors = %lu, ", ether_stats.framing_errors );
	printf( "crc_errors = %lu\n", ether_stats.crc_errors );
	printf( "packets_dropped = %lu, ", ether_stats.packets_dropped );
	printf( "packets_missed = %lu\n", ether_stats.packets_missed );
	printf( "deferred_transmits = %lu, ", ether_stats.deferred_transmits );
	printf( "late_collisions = %lu, ", ether_stats.late_collisions );
	printf( "carrier_lost = %lu\n", ether_stats.carrier_lost );
	printf( "failed_retries = %lu, ", ether_stats.no_more_retries );
	printf( "single_retries = %lu, ", ether_stats.single_retries );
	printf( "many_retries = %lu\n", ether_stats.multiple_retries );
	printf( "average_tdr_value = %lu\n", ether_stats.average_tdr_value );
}

int main()
{
	int	result, error_code;
	/* Arbitrary physical address */
	unsigned char	physical_address[PHYSICAL_ADDRESS_SIZE] =
		{ 0x22, 0x44, 0x88, 0x88, 0x44, 0x22 };
	ETHER_STATS	ether_stats;
	int	receive_packet_length;	
	unsigned char	receive_packet[MAX_PACKET_LENGTH];
	unsigned char	failed_packet_data[FAILED_PACKET_LENGTH];

	Channel	cancel, *to_b431, *from_b431;

	ChanInit( &cancel );

	/* Channels to / from IMS B431 device driver obtained from
	   configuration environment */

	to_b431 = (Channel *) get_param( 4 );
	from_b431 = (Channel *) get_param( 3 );

	/* Perform an internal loopback, request and then print out
	   Ethernet statistics. Then do the same for external loopback. */

	printf( "IMS-F006: loopback test\n" );

	/* Internal loopback test */

	printf( "Internal loopback..." );
	result = B431_Internal_Loopback( from_b431, to_b431,
				physical_address, &error_code );
	printf( "complete, result was %d, test %s\n",
		result, (result != TEST_PASSED) ? "failed" : "passed" );

	/* Request and display Ethernet statistics, note that it is
	   not necessary to fork into parallel processes in order to receive
	   the statistics after calling B431_Ether_Stats(). */

	B431_Ether_Stats( to_b431 );

	while ( B431_Waitfor_Event( from_b431, &cancel, &ether_stats,
		receive_packet, &receive_packet_length,
		&error_code, failed_packet_data ) != B431_ETHER_STATS )
		;
	print_ether_stats( ether_stats );

	/* External loopback test */

	printf( "External loopback..." );
	result = B431_External_Loopback( from_b431, to_b431,
				physical_address, &error_code );
	printf( "complete, result was %d, test %s\n",
		result, (result != TEST_PASSED) ? "failed" : "passed" );

	/* Request and display Ethernet statistics, note that it is
	   not necessary to fork into parallel processes in order to receive
	   the statistics after calling B431_Ether_Stats(). */

	B431_Ether_Stats( to_b431 );

	while ( B431_Waitfor_Event( from_b431, &cancel, &ether_stats,
		receive_packet, &receive_packet_length,
		&error_code, failed_packet_data ) != B431_ETHER_STATS )
		;
	print_ether_stats( ether_stats );

	/* Terminate the IMS B431 device driver */

	B431_Terminate( to_b431 );

	while ( B431_Waitfor_Event( from_b431, &cancel, &ether_stats,
		receive_packet, &receive_packet_length,
		&error_code, failed_packet_data ) != B431_TERMINATE )
		;

	exit_terminate(0);
}
